@@ -1,29 +1,30 @@
-from __future__ import print_function, division
+from __future__ import division
+from __future__ import print_function
 
-import os
 import gc
+import multiprocessing
+import os
 import platform
 import sys
-import time
 import threading
+import time
 from collections import defaultdict
-import multiprocessing
 
 import pytest
 from process_tests import TestProcess
 from process_tests import dump_on_error
 from process_tests import wait_for_strings
-
 from redis import StrictRedis
 
 from redis_lock import AlreadyAcquired
 from redis_lock import InvalidTimeout
 from redis_lock import Lock
 from redis_lock import NotAcquired
-from redis_lock import TimeoutTooLarge
-from redis_lock import TimeoutNotUsable
 from redis_lock import NotExpirable
+from redis_lock import TimeoutNotUsable
+from redis_lock import TimeoutTooLarge
 from redis_lock import reset_all
+
 from conf import HELPER
 from conf import TIMEOUT
 from conf import UDS_PATH
@@ -409,14 +410,6 @@ def test_bogus_release(conn):
     lock2.release()
 
 
-def test_release_from_nonblocking_leaving_garbage(conn):
-    for _ in range(10):
-        lock = Lock(conn, 'release_from_nonblocking')
-        lock.acquire(blocking=False)
-        lock.release()
-        assert conn.llen('lock-signal:release_from_nonblocking') == 1
-
-
 def test_no_auto_renewal(conn):
     lock = Lock(conn, 'lock_renewal', expire=3, auto_renewal=False)
     assert lock._lock_renewal_interval is None
@@ -445,13 +438,31 @@ def test_auto_renewal(conn):
     assert lock._lock_renewal_thread is None
 
 
-def test_signal_expiration(conn):
-    """Signal keys expire within two seconds after releasing the lock."""
-    lock = Lock(conn, 'signal_expiration')
+def test_signal_cleanup_on_release(conn):
+    """After releasing a lock, the signal key should not remain."""
+    lock = Lock(conn, 'foo')
     lock.acquire()
     lock.release()
-    time.sleep(2)
-    assert conn.llen('lock-signal:signal_expiration') == 0
+    assert conn.llen('lock-signal:foo') == 0
+    assert conn.exists('lock-signal:foo') == 0
+
+
+def test_signal_cleanup_on_reset(conn):
+    """After resetting a lock, the signal key should not remain."""
+    lock = Lock(conn, 'foo')
+    lock.acquire()
+    lock.reset()
+    assert conn.llen('lock-signal:foo') == 0
+    assert conn.exists('lock-signal:foo') == 0
+
+
+def test_signal_cleanup_on_reset_all(conn):
+    """After resetting all locks, no signal keys should not remain."""
+    lock = Lock(conn, 'foo')
+    lock.acquire()
+    reset_all(conn)
+    assert conn.llen('lock-signal:foo') == 0
+    assert conn.exists('lock-signal:foo') == 0
 
 
 def test_reset_signalizes(make_conn, make_process):
@@ -524,3 +535,26 @@ def test_auto_renewal_stops_after_gc(conn):
 
     assert not lock_renewal_thread.is_alive()
     assert conn.get(name) is None
+
+
+def test_given_id(conn):
+    """It is possible to extend a lock using another instance of Lock with the
+    same name.
+    """
+    name = 'foobar'
+    key_name = 'lock:' + name
+    orig = Lock(conn, name, expire=100, id=b"a")
+    orig.acquire()
+    pytest.raises(TypeError, Lock, conn, name, id=object())
+    lock = Lock(conn, name, id=b"a")
+    pytest.raises(AlreadyAcquired, lock.acquire)
+    lock.extend(100)
+    lock.release()  # this works, note that this ain't the object that acquired the lock
+    pytest.raises(NotAcquired, orig.release)  # and this fails because lock was released above
+
+    assert conn.ttl(key_name) == -2
+
+
+def test_strict_check():
+    pytest.raises(ValueError, Lock, object(), name='foobar')
+    Lock(object(), name='foobar', strict=False)
